@@ -25,21 +25,21 @@ class Repository:
   def url(self) -> str:
     return f"https://github.com/{self.user}/{self.path.name}/blob"
 
-  def include_file(self):
+  def include_file(self, test: bool):
     for markdown in File.files(self):
       line2txt = {}
       logging.info("Markdown: %s", markdown.path)
       for include in Include.includes(markdown):
         logging.info("Include: %s", include.name)
         line2txt[include.line_num] = include.to_markdown()
-      with FileInput(markdown.path, inplace=True) as file:
+      with FileInput(markdown.path, inplace=not test) as file:
         for i, line in enumerate(file, 1):
           if i in line2txt:
             print(line2txt[i], end="")
           else:
             print(line, end="")
 
-  def relocate_include(self) -> None:
+  def relocate_include(self, test: bool) -> None:
     logging.debug("relocate_include(%s)", self)
 
     files, path2include = File.files(self), {}
@@ -68,7 +68,8 @@ class Repository:
         correct_path = found_include.path
         if str(correct_path) != str(actual_path):
           correct_path.parent.mkdir(exist_ok=True)
-          actual_path.rename(correct_path)
+          if not test:
+            actual_path.rename(correct_path)
           cnt += 1
           logging.info("Fixed %s -> %s", actual_path, correct_path)
           type2cnt[type(found_include)] -= 1
@@ -120,6 +121,7 @@ class File:
 
   @property
   def include_path(self) -> Path:
+    logging.debug("include_path(%s)", self)
     if self.repo.stem:
       include_path = self.path.parent / self.path.stem
     else:
@@ -130,6 +132,7 @@ class File:
 
   @classmethod
   def files(cls, repo: Repository) -> list[File]:
+    logging.debug("files(%s)", repo)
     if isinstance(repo, Gitbook):
       assert repo.summary
       return [Markdown(repo, repo.path / path) for path in re.findall(Markdown.RE, repo.summary.content)]
@@ -145,6 +148,7 @@ class Markdown(File):
     return st.lower().replace(' ', '-')
 
   def extract_summary(self) -> list[Markdown]:
+    logging.debug("extract_summary(%s)", self)
     assert self.path.name == "SUMMARY.md"
     return [Markdown(self.repo, self.repo.path / path) for path in re.findall(Markdown.RE, self.content)]
 
@@ -176,6 +180,7 @@ class IInclude(ABC):
 
   @property
   def path(self) -> Path:
+    logging.debug("path(%s)", self)
     return self.file.include_path / self.name
 
   def update_link(self, text: str) -> str:
@@ -191,6 +196,7 @@ class Include(IInclude):
 
   @classmethod
   def includes(cls, file: File) -> list[IInclude]:
+    logging.debug("includes(%s)", file)
     includes = []
     for line_num, txt in enumerate(file.path.read_text().split("\n"), 1):
       for cls_ in IInclude.__subclasses__():
@@ -210,7 +216,7 @@ class Include(IInclude):
     return fr'{{% {Include.OVERWRITE} [\'"](.*)[\'"] %}}'
 
   def to_markdown(self):
-    logging.debug("_include_to_markdown(%s)", self)
+    logging.debug("to_markdown(%s)", self)
     assert self.path.is_file(), f"{self.path} is not a file"
     return self.update_link(self.path.read_text())
 
@@ -225,8 +231,14 @@ class Repo(IInclude):
     return fr'{{% {Repo.OVERWRITE} [\'"](.*)[\'"] %}}'
 
   def to_markdown(self):
-    logging.debug("_repo_to_markdown(%s)", self.path)
-    assert self.path.is_dir(), f"{self.path} is not a directory"
+    logging.debug("to_markdown(%s)", self)
+    if self.path.is_file():
+      lines = ["{% tabs %}"]
+      lines += [f"{{% tab title=\'{self.path.name}\' %}}\n"]
+      lines += [self.path.read_text()]
+      lines += ["{% endtab %}"]
+      lines += ["{% endtabs %}\n"]
+      return self.update_link("\n".join(lines))
     lines = []
     ignored = [".gitignore"] + check_output("git ls-files --other", text=True, shell=True).splitlines()
     for file_glob in self.glob.split("|"):
@@ -255,7 +267,7 @@ class Link(IInclude):
     return fr'{{% {Link.OVERWRITE} [\'"](.*)[\'"] %}}'
 
   def to_markdown(self):
-    logging.debug("_link_to_markdown(%s)", self.path)
+    logging.debug("to_markdown(%s)", self.path)
     repo = self.file.repo
     assert self.path.is_file(), f"{self.path} is not a file"
     return f"[{self.path.name}]({repo.url}/{repo.deploy_branch}/{self.path.relative_to(repo.path)})\n"
@@ -267,6 +279,7 @@ class Image(IInclude):
 
   @property
   def path(self) -> Path:
+    logging.debug("path(%s)", self)
     return self.file.include_path.parent / Image.OVERWRITE / self.name
 
   @staticmethod
@@ -274,5 +287,5 @@ class Image(IInclude):
     return rf".*!\[.*\]\(.*{Image.OVERWRITE}/(.*.png)\)"
 
   def to_markdown(self):
-    logging.debug("_to_markdown(%s)", self)
+    logging.debug("to_markdown(%s)", self)
     return self.txt + "\n"
